/* 
   orxonox - the future of 3D-vertical-scrollers

   Copyright (C) 2004 orx

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   ### File Specific:
   main-programmer: Patrick Boenzli
*/

#define DEBUG_SPECIAL_MODULE DEBUG_MODULE_IMPORTER

#include "md2Model.h"

//#include <stdio.h>
//#include <stdlib.h>
//#include <string>
#include <fstream>


using namespace std;

/********************************************************************************
 *   MD2MODEL                                                                   *
 ********************************************************************************/

/**
   \brief standard constructor
   
   	creates a new model
*/
MD2Model::MD2Model () 
{
   this->setClassName ("MD2Model");
}


/**
   \brief standard deconstructor

*/
MD2Model::~MD2Model () 
{
  // delete what has to be deleted here
}


/********************************************************************************
 *   MD2LOADER                                                                  *
 ********************************************************************************/

/**
   \brief standard deconstructor
	creates a new model loader
*/
MD2Loader::MD2Loader()
{
   this->setClassName ("MD2Loader");
   /* initialize all data to initial state */
   memset(&this->header, 0, sizeof(tMd2Header));
   this->pSkins = NULL;
   this->pTexCoords = NULL;
   this->pTriangles = NULL;
   this->pFrames = NULL;
}

/**
   \brief standard deconstructor
*/
MD2Loader::~MD2Loader()
{}
  

/**
	\brief this is called by the client to open the .Md2 file, read it, then clean up
	\param model to load in
	\param file name to load
	\param texture name to load
*/
bool MD2Loader::importMD2(t3DModel *pModel, char *fileName, char *textureName)
{
	char strMessage[255] = {0};

	this->pFile = fopen(fileName, "rb");
	if( unlikely(!pFile)) 
	{
		PRINTF(1)("Couldn't open the MD2 File for loading. Exiting.\n");
		return false;
	}
	fread(&this->header, 1, sizeof(tMd2Header), pFile);
	/* check for the header version: make sure its a md2 file :) */
	if( likely(this->header.version != 8))
	{
		PRINTF(1)("Couldn't load file %s: invalid file format: stop loading\n", fileName);
		return false;
	}
	
	this->readMD2Data();
	this->convertDataStructures(pModel);

	if( likely((int)textureName))
	{
		tMaterialInfo textureInfo;
		strcpy(textureInfo.strFile, textureName);
		/* since there is only one texture for a .Md2 file, the ID is always 0 */
		textureInfo.texureId = 0;
		textureInfo.uTile = 1;
		/* we only have 1 material for a model */
		pModel->numOfMaterials = 1;
		//pModel->materialList.add(texture);
	}
	
	this->cleanUp();
	return true;
}

/**
	\brief This function reads in all of the model's data, except the animation frames
*/
void MD2Loader::readMD2Data()
{}

/**
	\brief this function fills in the animation list for each animation by name and frame
	\param model
*/
void MD2Loader::parseAnimations(t3DModel *pModel)
{}

/**
	\brief this function converts the .md2 structures to our own model and object structures: decompress
	\param model
*/
void MD2Loader::convertDataStructures(t3DModel *pModel)
{}


/**
	\brief this function conputes the normals of the model
	\param model
*/
void MD2Loader::computeNormals(t3DModel *pModel)
{}

/**
	\brief This function cleans up our allocated memory and closes the file
*/
void MD2Loader::cleanUp()
{}
